#[repr(i32)]pub enum ColumnType {
Show 19 variants
Unspecified = 0,
Bool = 1,
Int8 = 2,
Int16 = 3,
Int32 = 4,
Int64 = 5,
Uint8 = 6,
Uint16 = 7,
Uint32 = 8,
Uint64 = 9,
Float32 = 10,
Float64 = 11,
TimestampNanos = 12,
Date32 = 13,
Date64 = 14,
Time64 = 15,
Bytes = 16,
Json = 17,
Decimal128 = 18,
}Variants
Unspecified = 0
Bool = 1
Int8 = 2
Int16 = 3
Int32 = 4
Int64 = 5
Uint8 = 6
Uint16 = 7
Uint32 = 8
Uint64 = 9
Float32 = 10
Float64 = 11
TimestampNanos = 12
Date32 = 13
Date64 = 14
Time64 = 15
Bytes = 16
Json = 17
Decimal128 = 18
Implementations
Sourceimpl ColumnType
impl ColumnType
Sourceimpl ColumnType
impl ColumnType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.