pub struct BeginTransactionRequest {
pub context: Option<RequestContext>,
pub session_id: Vec<u8>,
pub isolation: i32,
}Fields
context: Option<RequestContext>session_id: Vec<u8>isolation: i32Implementations
Sourceimpl BeginTransactionRequest
impl BeginTransactionRequest
Sourcepub fn isolation(&self) -> IsolationLevel
pub fn isolation(&self) -> IsolationLevel
Returns the enum value of isolation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_isolation(&mut self, value: IsolationLevel)
pub fn set_isolation(&mut self, value: IsolationLevel)
Sets isolation to the provided enum value.