pub struct CancelQueryResponse {
pub outcome: i32,
pub durable: Option<DurableOutcome>,
}Fields
outcome: i32durable: Option<DurableOutcome>Implementations
Sourceimpl CancelQueryResponse
impl CancelQueryResponse
Sourcepub fn outcome(&self) -> CancelOutcome
pub fn outcome(&self) -> CancelOutcome
Returns the enum value of outcome, or the default if the field is set to an invalid enum value.
Sourcepub fn set_outcome(&mut self, value: CancelOutcome)
pub fn set_outcome(&mut self, value: CancelOutcome)
Sets outcome to the provided enum value.