pub struct ForeignKey {
pub id: u32,
pub name: String,
pub columns: Vec<u32>,
pub referenced_table: String,
pub referenced_columns: Vec<u32>,
pub on_delete: i32,
pub on_update: i32,
}Fields
id: u32name: Stringcolumns: Vec<u32>referenced_table: Stringreferenced_columns: Vec<u32>on_delete: i32on_update: i32Implementations
Sourceimpl ForeignKey
impl ForeignKey
Sourcepub fn on_delete(&self) -> ForeignKeyAction
pub fn on_delete(&self) -> ForeignKeyAction
Returns the enum value of on_delete, or the default if the field is set to an invalid enum value.
Sourcepub fn set_on_delete(&mut self, value: ForeignKeyAction)
pub fn set_on_delete(&mut self, value: ForeignKeyAction)
Sets on_delete to the provided enum value.
Sourcepub fn on_update(&self) -> ForeignKeyAction
pub fn on_update(&self) -> ForeignKeyAction
Returns the enum value of on_update, or the default if the field is set to an invalid enum value.
Sourcepub fn set_on_update(&mut self, value: ForeignKeyAction)
pub fn set_on_update(&mut self, value: ForeignKeyAction)
Sets on_update to the provided enum value.