pub struct QueryStatusResponse {
pub query_id: Vec<u8>,
pub phase: i32,
pub error: Option<ErrorDetail>,
pub durable: Option<DurableOutcome>,
}Fields
query_id: Vec<u8>phase: i32error: Option<ErrorDetail>durable: Option<DurableOutcome>Implementations
Sourceimpl QueryStatusResponse
impl QueryStatusResponse
Sourcepub fn phase(&self) -> QueryPhase
pub fn phase(&self) -> QueryPhase
Returns the enum value of phase, or the default if the field is set to an invalid enum value.
Sourcepub fn set_phase(&mut self, value: QueryPhase)
pub fn set_phase(&mut self, value: QueryPhase)
Sets phase to the provided enum value.